module.exports = defineTest({
	description: 'removes unused nested statements'
});
